@@ -11,11 +11,16 @@ class Stats(object):
 
         telemetry (bool, optional): Enable or disable Telemetry
             (defaults to True)
+
+        timeout (float or tuple, optional): Change the requests
+            connect and read timeout. Pass a tuple to specify
+            both values separately or a float to set both to it.
+            (defaults to 5.0 for both)
     """
 
-    def __init__(self, domain, token, telemetry=True):
+    def __init__(self, domain, token, telemetry=True, timeout=5.0):
         self.domain = domain
-        self.client = RestClient(jwt=token, telemetry=telemetry)
+        self.client = RestClient(jwt=token, telemetry=telemetry, timeout=timeout)
 
     def _url(self, action):
         return 'https://{}/api/v2/stats/{}'.format(self.domain, action)
@@ -25,7 +30,6 @@ class Stats(object):
 
         Returns: An integer.
 
-
         See: https://auth0.com/docs/api/management/v2#!/Stats/get_active_users
         """
 
@@ -35,10 +39,10 @@ class Stats(object):
         """Gets the daily stats for a particular period.
 
         Args:
-           from_date (str): The first day of the period (inclusive) in
+           from_date (str, optional): The first day of the period (inclusive) in
               YYYYMMDD format.
 
-           to_date (str): The last day of the period (inclusive) in
+           to_date (str, optional): The last day of the period (inclusive) in
               YYYYMMDD format.
 
         See: https://auth0.com/docs/api/management/v2#!/Stats/get_daily
